@@ -17,7 +17,7 @@ dhyperb <- function(x, mu = 0, delta = 1, alpha = 1, beta = 0,
 ### DJS 28/7/10
 ### DJS 05/09/06
 phyperb <- function(q, mu = 0, delta = 1, alpha = 1, beta = 0,
-                    param = c(mu, delta, alpha, beta), log.p = FALSE,
+                    param = c(mu, delta, alpha, beta),
                     lower.tail = TRUE, subdivisions = 100,
                     intTol = .Machine$double.eps^0.25,
                     valueOnly = TRUE, ...){
@@ -27,9 +27,8 @@ phyperb <- function(q, mu = 0, delta = 1, alpha = 1, beta = 0,
 
   param <- as.numeric(param)
 
-  pghyp(q, param = c(param, 1), log.p = log.p,
-        lower.tail = lower.tail, subdivisions = subdivisions,
-        intTol = intTol,
+  pghyp(q, param = c(param, 1), lower.tail = lower.tail,
+        subdivisions = subdivisions, intTol = intTol,
         valueOnly = valueOnly, ...)
 } ## End of phyperb()
 
@@ -38,7 +37,7 @@ phyperb <- function(q, mu = 0, delta = 1, alpha = 1, beta = 0,
 ### DJS 28/7/10
 ### DJS 06/09/06
 qhyperb <- function(p, mu = 0, delta = 1, alpha = 1, beta = 0,
-                    param = c(mu, delta, alpha, beta), log.p = FALSE,
+                    param = c(mu, delta, alpha, beta),
                     lower.tail = TRUE, method = c("spline", "integrate"),
                     nInterpol = 501, uniTol = .Machine$double.eps^0.25,
                     subdivisions = 100, intTol = uniTol, ...) {
@@ -48,8 +47,7 @@ qhyperb <- function(p, mu = 0, delta = 1, alpha = 1, beta = 0,
 
   param <- as.numeric(param)
 
-  qghyp(p, param = c(param,1), log.p = log.p,
-        lower.tail = lower.tail, method = method,
+  qghyp(p, param = c(param,1), lower.tail = lower.tail, method = method,
         nInterpol = nInterpol, uniTol = uniTol,
         subdivisions = subdivisions, intTol = intTol, ...)
 } # End of qhyperb()
